# Logging & Security — REST API Reference

- [Log API](logs.md) — Query application and audit logs
- [Incident API](incidents.md) — View and manage security incidents
- [Reporting Events](reporting_events.md) — Report events from a web page
